@@ -61,6 +61,11 @@ Query = namedtuple('Query', ['query', 'successful', 'mutating'])
 
 PACKAGE_ROOT = os.path.dirname(__file__)
 
+# no-op logging handler
+class NullHandler(logging.Handler):
+    def emit(self, record):
+        pass
+
 class MyCli(object):
 
     default_prompt = '\\t \\u@\\h:\\d> '
@@ -75,7 +80,7 @@ class MyCli(object):
     ]
 
     system_config_files = [
-		'/etc/myclirc',
+        '/etc/myclirc',
     ]
 
     default_config_file = os.path.join(PACKAGE_ROOT, 'myclirc')
@@ -107,10 +112,12 @@ class MyCli(object):
         special.set_timing_enabled(c['main'].as_bool('timing'))
         self.table_format = c['main']['table_format']
         self.syntax_style = c['main']['syntax_style']
+        self.less_chatty = c['main'].as_bool('less_chatty')
         self.cli_style = c['colors']
         self.wider_completion_menu = c['main'].as_bool('wider_completion_menu')
         c_dest_warning = c['main'].as_bool('destructive_warning')
         self.destructive_warning = c_dest_warning if warn is None else warn
+        self.login_path_as_host = c['main'].as_bool('login_path_as_host')
 
         # Write user config if system config wasn't the last config loaded.
         if c.filename not in self.system_config_files:
@@ -132,6 +139,7 @@ class MyCli(object):
         prompt_cnf = self.read_my_cnf_files(self.cnf_files, ['prompt'])['prompt']
         self.prompt_format = prompt or prompt_cnf or c['main']['prompt'] or \
                              self.default_prompt
+        self.prompt_continuation_format = c['main']['prompt_continuation']
 
         self.query_history = []
 
@@ -234,7 +242,13 @@ class MyCli(object):
                      'DEBUG': logging.DEBUG
                      }
 
-        handler = logging.FileHandler(os.path.expanduser(log_file))
+        # Disable logging if value is NONE by switching to a no-op handler
+        # Set log level to a high value so it doesn't even waste cycles getting called.
+        if log_level.upper() == "NONE":
+            handler = NullHandler()
+            log_level = "CRITICAL"
+        else:
+            handler = logging.FileHandler(os.path.expanduser(log_file))
 
         formatter = logging.Formatter(
             '%(asctime)s (%(process)d/%(threadName)s) '
@@ -426,17 +440,19 @@ class MyCli(object):
 
         key_binding_manager = mycli_bindings()
 
-        print('Version:', __version__)
-        print('Chat: https://gitter.im/dbcli/mycli')
-        print('Mail: https://groups.google.com/forum/#!forum/mycli-users')
-        print('Home: http://mycli.net')
-        print('Thanks to the contributor -', thanks_picker([author_file, sponsor_file]))
+        if not self.less_chatty:
+            print('Version:', __version__)
+            print('Chat: https://gitter.im/dbcli/mycli')
+            print('Mail: https://groups.google.com/forum/#!forum/mycli-users')
+            print('Home: http://mycli.net')
+            print('Thanks to the contributor -', thanks_picker([author_file, sponsor_file]))
 
         def prompt_tokens(cli):
             return [(Token.Prompt, self.get_prompt(self.prompt_format))]
 
         def get_continuation_tokens(cli, width):
-            return [(Token.Continuation, ' ' * (width - 3) + '-> ')]
+            continuation_prompt = self.get_prompt(self.prompt_continuation_format)
+            return [(Token.Continuation, ' ' * (width - len(continuation_prompt)) + continuation_prompt)]
 
         get_toolbar_tokens = create_toolbar_tokens_func(self.completion_refresher.is_refreshing)
 
@@ -453,7 +469,7 @@ class MyCli(object):
                                       ])
         with self._completer_lock:
             buf = CLIBuffer(always_multiline=self.multi_line, completer=self.completer,
-                    history=FileHistory(os.path.expanduser('~/.mycli-history')),
+                    history=FileHistory(os.path.expanduser(os.environ.get('MYCLI_HISTFILE', '~/.mycli-history'))),
                     complete_while_typing=Always(), accept_action=AcceptAction.RETURN_DOCUMENT)
 
             if self.key_bindings == 'vi':
@@ -610,7 +626,8 @@ class MyCli(object):
                 self.query_history.append(query)
 
         except EOFError:
-            self.output('Goodbye!')
+            if not self.less_chatty:
+                self.output('Goodbye!')
 
     def output(self, text, **kwargs):
         if self.logfile:
@@ -670,13 +687,24 @@ class MyCli(object):
 
     def get_prompt(self, string):
         sqlexecute = self.sqlexecute
+        host = self.login_path if self.login_path and self.login_path_as_host else sqlexecute.host
         string = string.replace('\\u', sqlexecute.user or '(none)')
-        string = string.replace('\\h', sqlexecute.host or '(none)')
+        string = string.replace('\\h', host or '(none)')
         string = string.replace('\\d', sqlexecute.dbname or '(none)')
         string = string.replace('\\t', sqlexecute.server_type()[0] or 'mycli')
         string = string.replace('\\n', "\n")
         return string
 
+    def run_query(self, query, table_format=None):
+        """Runs query"""
+        results = self.sqlexecute.run(query)
+        for result in results:
+            title, cur, headers, status = result
+            table_format = self.table_format if table_format else None
+            output = format_output(title, cur, headers, None, table_format)
+            for line in output:
+                click.echo(line)
+
 @click.command()
 @click.option('-h', '--host', envvar='MYSQL_HOST', help='Host address of the database.')
 @click.option('-P', '--port', envvar='MYSQL_TCP_PORT', type=int, help='Port number to use for connection. Honors '
@@ -722,11 +750,14 @@ class MyCli(object):
               help='Enable/disable LOAD DATA LOCAL INFILE.')
 @click.option('--login-path', type=str,
               help='Read this path from the login file.')
+@click.option('-e', '--execute',  type=str,
+              help='Execute query to the database.')
 @click.argument('database', default='', nargs=1)
 def cli(database, user, host, port, socket, password, dbname,
         version, prompt, logfile, defaults_group_suffix, defaults_file,
         login_path, auto_vertical_output, local_infile, ssl_ca, ssl_capath,
-        ssl_cert, ssl_key, ssl_cipher, ssl_verify_server_cert, table, warn):
+        ssl_cert, ssl_key, ssl_cipher, ssl_verify_server_cert, table, warn,
+        execute):
 
     if version:
         print('Version:', __version__)
@@ -763,6 +794,15 @@ def cli(database, user, host, port, socket, password, dbname,
             '\thost: %r'
             '\tport: %r', database, user, host, port)
 
+    #  --execute argument
+    if execute:
+        try:
+            mycli.run_query(execute, table_format=table)
+            exit(0)
+        except Exception as e:
+            click.secho(str(e), err=True, fg='red')
+            exit(1)
+
     if sys.stdin.isatty():
         mycli.run_cli()
     else:
@@ -778,17 +818,12 @@ def cli(database, user, host, port, socket, password, dbname,
                 confirm_destructive_query(stdin_text) is False):
             exit(0)
         try:
-            results = mycli.sqlexecute.run(stdin_text)
-            for result in results:
-                title, cur, headers, status = result
-                table_format = mycli.table_format if table else None
-                output = format_output(title, cur, headers, None, table_format)
-                for line in output:
-                    click.echo(line)
+            mycli.run_query(stdin_text, table_format=table)
         except Exception as e:
             click.secho(str(e), err=True, fg='red')
             exit(1)
 
+
 def format_output(title, cur, headers, status, table_format, expanded=False, max_width=None):
     output = []
     if title:  # Only print the title if it's not None.
@@ -800,7 +835,7 @@ def format_output(title, cur, headers, status, table_format, expanded=False, max
         elif table_format is not None:
             rows = list(cur)
             tabulated, frows = tabulate(rows, headers, tablefmt=table_format,
-                missingval='<null>')
+                                        missingval='<null>')
             if (max_width and rows and
                     content_exceeds_width(frows[0], max_width) and
                     headers):
