@@ -1,5 +1,6 @@
 import os
 import re
+import locale
 import logging
 import subprocess
 from io import open
@@ -14,7 +15,7 @@ from .utils import handle_cd_command
 
 TIMING_ENABLED = False
 use_expanded_output = False
-ORIGINAL_PAGER = os.environ.get('PAGER', '')
+PAGER_ENABLED = True
 
 @export
 def set_timing_enabled(val):
@@ -22,25 +23,38 @@ def set_timing_enabled(val):
     TIMING_ENABLED = val
 
 @export
-def get_original_pager():
-    return ORIGINAL_PAGER
+def set_pager_enabled(val):
+    global PAGER_ENABLED
+    PAGER_ENABLED = val
+
+@export
+def is_pager_enabled():
+    return PAGER_ENABLED
 
 @export
 @special_command('pager', '\\P [command]', 'Set PAGER. Print the query results via PAGER', arg_type=PARSED_QUERY, aliases=('\\P', ), case_sensitive=True)
 def set_pager(arg, **_):
-    if not arg:
-        if not ORIGINAL_PAGER:
-            os.environ.pop('PAGER', None)
-            msg = 'Reset pager.'
-        else:
-            os.environ['PAGER'] = ORIGINAL_PAGER
-            msg = 'Reset pager back to default. Default: %s' % ORIGINAL_PAGER
-    else:
+    if arg:
         os.environ['PAGER'] = arg
         msg = 'PAGER set to %s.' % arg
+        set_pager_enabled(True)
+    else:
+        if 'PAGER' in os.environ:
+            msg = 'PAGER set to %s.' % os.environ['PAGER']
+        else:
+            # This uses click's default per echo_via_pager.
+            msg = 'Pager enabled.'
+        set_pager_enabled(True)
 
     return [(None, None, None, msg)]
 
+@export
+@special_command('nopager', '\\n', 'Disable pager, print to stdout.',
+                 arg_type=NO_QUERY, aliases=('\\n', ), case_sensitive=True)
+def disable_pager():
+    set_pager_enabled(False)
+    return [(None, None, None, 'Pager disabled.')]
+
 @special_command('\\timing', '\\t', 'Toggle timing of commands.', arg_type=NO_QUERY, aliases=('\\t', ), case_sensitive=True)
 def toggle_timing():
     global TIMING_ENABLED
@@ -218,6 +232,11 @@ def execute_system_command(arg, **_):
         output, error = process.communicate()
         response = output if not error else error
 
+        # Python 3 returns bytes. This needs to be decoded to a string.
+        if isinstance(response, bytes):
+            encoding = locale.getpreferredencoding(False)
+            response = response.decode(encoding)
+
         return [(None, None, None, response)]
     except OSError as e:
         return [(None, None, None, 'OSError: %s' % e.strerror)]
