@@ -19,32 +19,23 @@ _logger = logging.getLogger(__name__)
 
 class SQLCompleter(Completer):
     keywords = ['ACCESS', 'ADD', 'ALL', 'ALTER TABLE', 'AND', 'ANY', 'AS',
-                'ASC', 'AUDIT', 'BEFORE', 'BEGIN', 'BETWEEN', 'BINARY', 'BY',
-                'CASE', 'CHANGE MASTER TO', 'CHAR', 'CHECK', 'CLUSTER',
-                'COLUMN', 'COMMENT', 'COMPRESS', 'COMMIT', 'CONNECT', 'COPY',
-                'CREATE', 'CURRENT', 'DATABASE', 'DATE', 'DECIMAL', 'DEFAULT',
-                'DELETE FROM', 'DELIMITER', 'DESC', 'DESCRIBE', 'DISTINCT',
-                'DROP', 'ELSE', 'ENCODING', 'END', 'ESCAPE', 'EXCLUSIVE',
-                'EXISTS', 'EXTENSION', 'FILE', 'FLOAT', 'FOR', 'FORMAT',
-                'FORCE_QUOTE', 'FORCE_NOT_NULL', 'FREEZE', 'FROM', 'FULL',
-                'FUNCTION', 'GRANT', 'GROUP BY', 'HAVING', 'HEADER', 'HOST',
-                'IDENTIFIED', 'IMMEDIATE', 'IN', 'INCREMENT', 'INDEX',
-                'INITIAL', 'INSERT INTO', 'INTEGER', 'INTERSECT', 'INTO',
-                'INTERVAL', 'IS', 'JOIN', 'LEFT', 'LEVEL', 'LIKE', 'LIMIT',
-                'LOCK', 'LOG', 'LOGS', 'LONG', 'MASTER', 'MINUS', 'MODE',
-                'MODIFY', 'NOAUDIT', 'NOCOMPRESS', 'NOT', 'NOWAIT', 'NULL',
-                'NUMBER', 'OIDS', 'OF', 'OFFLINE', 'OFFSET', 'ON', 'ONLINE',
-                'OPTION', 'OR', 'ORDER BY', 'OUTER', 'OWNER', 'PASSWORD',
-                'PCTFREE', 'PORT', 'PRIMARY', 'PRIOR', 'PRIVILEGES',
-                'PROCESSLIST', 'PURGE', 'QUOTE', 'RAW', 'RENAME', 'REPAIR',
-                'RESOURCE', 'RESET', 'REVOKE', 'RIGHT', 'ROLLBACK', 'ROW',
-                'ROWID', 'ROWNUM', 'ROWS', 'SELECT', 'SESSION', 'SET', 'SHARE',
-                'SHOW', 'SIZE', 'SLAVE', 'SLAVES', 'SMALLINT', 'START', 'STOP',
-                'SUCCESSFUL', 'SYNONYM', 'SYSDATE', 'TABLE', 'TEMPLATE',
-                'THEN', 'TO', 'TRANSACTION', 'TRIGGER', 'TRUNCATE', 'UID',
-                'UNION', 'UNIQUE', 'UPDATE', 'USE', 'USER', 'USING',
-                'VALIDATE', 'VALUES', 'VARCHAR', 'VARCHAR2', 'VIEW', 'WHEN',
-                'WHENEVER', 'WHERE', 'WITH']
+                'ASC', 'BEFORE', 'BEGIN', 'BETWEEN', 'BINARY', 'BY',
+                'CASE', 'CHAR', 'CHECK', 'COLUMN', 'COMMENT', 'COMMIT',
+                'CHANGE MASTER TO', 'CREATE', 'CURRENT', 'DATABASE', 'DATE',
+                'DECIMAL', 'DEFAULT', 'DELETE FROM', 'DELIMITER', 'DESC',
+                'DESCRIBE', 'DROP', 'ELSE', 'END', 'ESCAPE', 'EXISTS',
+                'FILE', 'FLOAT', 'FOR', 'FORMAT', 'FROM', 'FULL', 'FUNCTION', 'GRANT',
+                'GROUP BY', 'HAVING', 'HOST', 'IDENTIFIED', 'IN', 'INCREMENT', 'INDEX',
+                'INSERT INTO', 'INTEGER', 'INTO', 'INTERVAL', 'IS', 'JOIN', 'LEFT',
+                'LEVEL', 'LIKE', 'LIMIT', 'LOCK', 'LOGS', 'LONG', 'MASTER', 'MODE',
+                'MODIFY', 'NOT', 'NULL', 'NUMBER', 'OFFSET', 'ON', 'OPTION', 'OR',
+                'ORDER BY', 'OUTER', 'OWNER', 'PASSWORD', 'PORT', 'PRIMARY',
+                'PRIVILEGES', 'PROCESSLIST', 'PURGE', 'RENAME', 'REPAIR', 'RESET',
+                'REVOKE', 'RIGHT', 'ROLLBACK','ROW', 'ROWS', 'SELECT', 'SESSION', 'SET',
+                'SHARE', 'SHOW', 'SLAVE', 'SMALLINT', 'START', 'STOP', 'TABLE', 'THEN',
+                'TO', 'TRANSACTION', 'TRIGGER', 'TRUNCATE', 'UNION', 'UNIQUE', 'UPDATE',
+                'USE', 'USER', 'USING', 'VALUES', 'VARCHAR', 'VIEW', 'WHEN', 'WHERE',
+                'WITH']
 
     functions = ['AVG', 'COUNT', 'DISTINCT', 'FIRST', 'FORMAT', 'LAST',
                  'LCASE', 'LEN', 'MAX', 'MIN', 'MID', 'NOW', 'ROUND', 'SUM',
@@ -201,6 +192,7 @@ class SQLCompleter(Completer):
 
     def reset_completions(self):
         self.databases = []
+        self.show_items = []
         self.dbname = ''
         self.dbmetadata = {'tables': {}, 'views': {}, 'functions': {}}
         self.all_completions = set(self.keywords + self.functions)
